==> opensaml-saml-api-3.3.0-sources.jar: org/opensaml/saml/common/messaging/context/navigate/AttributeConsumerServiceLookupFunction.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.saml.common.messaging.context.navigate;

import javax.annotation.Nullable;

import org.opensaml.messaging.context.navigate.ContextDataLookupFunction;
import org.opensaml.saml.common.messaging.context.AttributeConsumingServiceContext;
import org.opensaml.saml.saml2.metadata.AttributeConsumingService;

/**
 * {@link Function} to return the {@link AttributeConsumingService} from the {@link AttributeConsumingServiceContext}.
 */
public class AttributeConsumerServiceLookupFunction implements
        ContextDataLookupFunction<AttributeConsumingServiceContext, AttributeConsumingService> {

    /** {@inheritDoc} */
    @Override @Nullable public AttributeConsumingService apply(@Nullable final AttributeConsumingServiceContext input) {
        if (null == input) {
            return null;
        }
        return input.getAttributeConsumingService();
    }

}

==> opensaml-saml-api-3.4.4-sources.jar: org/opensaml/saml/common/messaging/context/navigate/AttributeConsumerServiceLookupFunction.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.saml.common.messaging.context.navigate;

import javax.annotation.Nullable;

import org.opensaml.messaging.context.navigate.ContextDataLookupFunction;
import org.opensaml.saml.common.messaging.context.AttributeConsumingServiceContext;
import org.opensaml.saml.saml2.metadata.AttributeConsumingService;

/**
 * {@link com.google.common.base.Function} to return the {@link AttributeConsumingService}
 * from the {@link AttributeConsumingServiceContext}.
 */
public class AttributeConsumerServiceLookupFunction implements
        ContextDataLookupFunction<AttributeConsumingServiceContext, AttributeConsumingService> {

    /** {@inheritDoc} */
    @Nullable public AttributeConsumingService apply(@Nullable final AttributeConsumingServiceContext input) {
        if (null == input) {
            return null;
        }
        return input.getAttributeConsumingService();
    }

}
